@@ -7,7 +7,7 @@ class InputObjectInfo(ObjectInfo):
     Implementation of ObjectInfo to be used to characterize objects which are to be loaded from a csv file.
     """
     def __init__(self, input_file, initial_mask=None, initial_transit_mask=None,
-                 star_info=None, aperture_file=None, outliers_sigma=3, high_rms_enabled=True, high_rms_threshold=2.5,
+                 star_info=None, outliers_sigma=3, high_rms_enabled=True, high_rms_threshold=2.5,
                  high_rms_bin_hours=4, smooth_enabled=False,
                  auto_detrend_enabled=False, auto_detrend_method="cosine", auto_detrend_ratio=0.25,
                  auto_detrend_period=None, prepare_algorithm=None):
@@ -15,7 +15,7 @@ class InputObjectInfo(ObjectInfo):
         @param input_file: the file to be used for loading the light curve
         @param initial_mask: an array of time ranges provided to mask them into the initial object light curve.
         @param star_info: input star information
-        @param aperture_file: the file containing 1s and 0s specifying the user selected aperture
+        @param apertures: the aperture pixels [col, row] per sector as a dictionary.
         @param outliers_sigma: sigma used to cut upper outliers.
         @param high_rms_enabled: whether RMS masking is enabled
         @param high_rms_threshold: RMS masking threshold
@@ -27,7 +27,7 @@ class InputObjectInfo(ObjectInfo):
         @param auto_detrend_period: the fixed detrend period (disables auto_detrend)
         @param prepare_algorithm: custom curve preparation logic
         """
-        super().__init__(initial_mask, initial_transit_mask, star_info, aperture_file,
+        super().__init__(initial_mask, initial_transit_mask, star_info, None,
                          outliers_sigma, high_rms_enabled, high_rms_threshold, high_rms_bin_hours, smooth_enabled,
                          auto_detrend_enabled, auto_detrend_method, auto_detrend_ratio, auto_detrend_period,
                          prepare_algorithm)
